@@ -8,10 +8,10 @@ from torch import cuda
 from torch.autograd import Variable
 from torch.utils.data import DataLoader
 from torchvision.transforms import Compose
-from data_loader import RescaleT
-from data_loader import SalObjDataset
-from data_loader import ToTensorLab
-from model import U2NET
+from .data_loader import RescaleT
+from .data_loader import SalObjDataset
+from .data_loader import ToTensorLab
+from .model import U2NET
 
 
 class DataSetIter:
